.. _model_attributes_sed:
.. currentmodule:: hydromt_wflow.wflow_sediment

Model attributes
================

A wflow_sediment model in HydroMT also has a set of specific attributes, on top of the ones 
from the model API. These are (same as wflow):

.. autosummary::
   :toctree: ../../generated/
   :nosignatures:

   ~WflowSedimentModel.flwdir
   ~WflowSedimentModel.basins
   ~WflowSedimentModel.rivers